Crate bpflint

A linter for BPF C code.

Structs

LintMatch
Details about a linter match.
Point
A position in a multi-line text document, in terms of rows and columns.
Range
A range of positions in a multi-line text document, both in terms of bytes and of rows and columns.

Functions

lint
Lint code using the default set of lints.
report_terminal
Report a lint match in terminal style.